@@ -1,9 +1,9 @@
 package Text::Xslate::Symbol;
-use 5.010;
 use Any::Moose;
 
 use overload
-    '""' => sub{ $_[0]->id },
+    bool => sub() { 1 },
+    '""' => sub   { $_[0]->id },
     fallback => 1,
 ;
 
